DateTimeFormatConstants class

Constructors

DateTimeFormatConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

day → const String
ddMMMFormat → const String
ddMMMMyyyy → const String
ddMMMyyyy → const String
ddMMMyyyyFormat → const String
ddMMyyyy → const String
ddMMyyyyFormat → const String
defaultDateTimeFormat → const String
dMMMMyyyyFormat → const String
dMMMyyyyFormat → const String
dMMMyyyyHHmmFormatEN → const String
dMMMyyyyHHmmFormatID → const String
eEEEdMMMMyFormat → const String
hHddMMyyyy → const String
iso8601WithMillisecondsOnly → const String
mMMddyyyy → const String
mMMMddyyyy → const String
mMMyyyyFormat → const String
mmyy → const String
month → const String
monthFull → const String
timeBooking → const String
timeddMMyyyy → const String
timeHHmmFormatEN → const String
timeHHmmFormatID → const String
timeHHmmssFormatEN → const String
timeHHmmssFormatID → const String
timeMMMMyyyy → const String
timeSeparater → const String
weekday → const String
year → const String
yyyyMMdd → const String