DateTimeUtils class

Constructors

DateTimeUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

format(int timestamp, String format) String
getDate(DateTime dateTime, {String? format}) String
getDateFromTimeStamp(int timestamp) String
getTimeAndDate(int timestamp) String
getTimeAndDay(DateTime dateTime) String
getTimeBooking(DateTime time) String
parse(int timestamp) DateTime
parseRfc822(String input) DateTime?
tryParseDateTime(dynamic data) DateTime?